#!@@SHELL@@
#
# opkhelper
# lib/architecture
# Functions for determining the target architecture.
#
# Copyright (C) 2012 Patrick "P. J." McDermott
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

. @@LIBDIR@@/opkhelper/controlfields

oh_is_buildable()
{
	_pkgarch=$(oh_get_field "${1}" Architecture)

	# "all" or "any".
	if [ "${_pkgarch}" = all -o "${_pkgarch}" = any ]; then
		return 0
	fi

	# Platform.
	if [ -n "$(echo "${_pkgarch}" | grep -E '^[^-]+$')" ]; then
		return [ "${_pkgarch}" = "${OH_HOST_PLATFORM}" ]
	fi

	# Tokenize the 3-tuple binary architecture.
	IFS=- read _pkgcpu _pkgkernel _pkglibs <<EOF
${_pkgarch}
EOF

	# Test each element of the tuple.
	[ "${_pkgcpu}" != any -a "${_pkgcpu}" != "${OH_HOST_ARCH_CPU}" ] &&
		return 1
	[ "${_pkgkernel}" != any -a "${_pkgkernel}" != "${OH_HOST_ARCH_KERNEL}" ] &&
		return 1
	[ "${_pkglibs}" != any -a "${_pkglibs}" != "${OH_HOST_ARCH_LIBS}" ] &&
		return 1

	return 0
}

oh_get_package_architecture()
{
	_pkgarch=$(oh_get_field "${1}" Architecture)

	# "all".
	if [ "${_pkgarch}" = all ]; then
		echo all
		return 0
	fi

	if [ -n "${OH_HOST_PLATFORM}" ]; then
		echo "${OH_HOST_PLATFORM}"
	else
		echo "${OH_HOST_ARCH_DIST}"
	fi

	return 0
}
